@@ -83,8 +83,6 @@ static uudecode_exit_code_t read_stduu (const char *inname, const char *outname)
 static uudecode_exit_code_t read_base64(const char *inname, const char *outname);
 static uudecode_exit_code_t decode (const char * in_name);
 
-static bool do_base64 = false;
-
 #ifndef NUL
 #define NUL '\0'
 #endif
@@ -191,7 +189,6 @@ read_base64 (char const * inname, char const * outname)
 
       if (fwrite (buf_out, outlen, 1, stdout) != 1)
         fserr (UUDECODE_EXIT_NO_OUTPUT, "fwrite", outname);
-      TRY_PUTCHAR ('\n');
     }
 
   return UUDECODE_EXIT_SUCCESS;
@@ -304,15 +301,13 @@ decode_fname (char * buf)
 
   {
     char * tmp = out + sz + 4;
-    struct base64_decode_context ctx;
 
     if (out == NULL)
       fserr(UUDECODE_EXIT_NO_MEM, "malloc", _("output file name"));
 
     memcpy(out, buf, sz);
-    out[sz+0] = out[sz+1] = '=';
-    out[sz+2] = '\0';
-    if (! base64_decode (out, sz + 2, tmp, &sz))
+    out[sz] = '\0';
+    if (! base64_decode (out, sz, tmp, &sz))
       die (UUDECODE_EXIT_INVALID, _("invalid base64 encoded name: %s"), buf);
     memcpy (buf, tmp, sz);
     buf[sz] = '\0';
@@ -338,6 +333,7 @@ decode (char const * inname)
   bool  allocated_outname = false;
   bool  encoded_fname = false;
   uudecode_exit_code_t rval;
+  bool  do_base64 = false;
 
   /* Search for header line.  */
 
